==> plantuml-libs-5.2.0.tgz: package/distribution/aws-20210730/Resource/Compute/AmazonEc2R5GdInstance.md <==
# AmazonEc2R5GdInstance


```text
aws-20210730/Resource/Compute/AmazonEc2R5GdInstance
```

```text
include('aws-20210730/Resource/Compute/AmazonEc2R5GdInstance')
```



| Illustration | AmazonEc2R5GdInstance | AmazonEc2R5GdInstanceCard | AmazonEc2R5GdInstanceGroup |
| :---: | :---: | :---: | :---: |
| ![illustration for Illustration](../../../aws-20210730/Resource/Compute/AmazonEc2R5GdInstance.png) | ![illustration for AmazonEc2R5GdInstance](../../../aws-20210730/Resource/Compute/AmazonEc2R5GdInstance.Local.png) | ![illustration for AmazonEc2R5GdInstanceCard](../../../aws-20210730/Resource/Compute/AmazonEc2R5GdInstanceCard.Local.png) | ![illustration for AmazonEc2R5GdInstanceGroup](../../../aws-20210730/Resource/Compute/AmazonEc2R5GdInstanceGroup.Local.png) |




## AmazonEc2R5GdInstance

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://github.com/tmorin/plantuml-libs/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonEc2R5GdInstance
include('aws-20210730/Resource/Compute/AmazonEc2R5GdInstance')

' renders the element
AmazonEc2R5GdInstance('AmazonEc2R5GdInstance', 'Amazon Ec2 R5 Gd Instance', 'an optional tech label')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonEc2R5GdInstance
include('aws-20210730/Resource/Compute/AmazonEc2R5GdInstance')

' renders the element
AmazonEc2R5GdInstance('AmazonEc2R5GdInstance', 'Amazon Ec2 R5 Gd Instance', 'an optional tech label')
@enduml
```

## AmazonEc2R5GdInstanceCard

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://github.com/tmorin/plantuml-libs/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonEc2R5GdInstanceCard
include('aws-20210730/Resource/Compute/AmazonEc2R5GdInstance')

' renders the element
AmazonEc2R5GdInstanceCard('AmazonEc2R5GdInstanceCard', 'Amazon Ec2 R5 Gd Instance Card', 'an optional description')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonEc2R5GdInstanceCard
include('aws-20210730/Resource/Compute/AmazonEc2R5GdInstance')

' renders the element
AmazonEc2R5GdInstanceCard('AmazonEc2R5GdInstanceCard', 'Amazon Ec2 R5 Gd Instance Card', 'an optional description')
@enduml
```

## AmazonEc2R5GdInstanceGroup

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://github.com/tmorin/plantuml-libs/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonEc2R5GdInstanceGroup
include('aws-20210730/Resource/Compute/AmazonEc2R5GdInstance')

' renders the element
AmazonEc2R5GdInstanceGroup('AmazonEc2R5GdInstanceGroup', 'Amazon Ec2 R5 Gd Instance Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonEc2R5GdInstanceGroup
include('aws-20210730/Resource/Compute/AmazonEc2R5GdInstance')

' renders the element
AmazonEc2R5GdInstanceGroup('AmazonEc2R5GdInstanceGroup', 'Amazon Ec2 R5 Gd Instance Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

==> plantuml-libs-6.4.0.tgz: package/distribution/aws-20210730/Resource/Compute/AmazonEc2R5GdInstance.md <==
# AmazonEc2R5GdInstance


```text
aws-20210730/Resource/Compute/AmazonEc2R5GdInstance
```

```text
include('aws-20210730/Resource/Compute/AmazonEc2R5GdInstance')
```



| Illustration | AmazonEc2R5GdInstance | AmazonEc2R5GdInstanceCard | AmazonEc2R5GdInstanceGroup |
| :---: | :---: | :---: | :---: |
| ![illustration for Illustration](../../../aws-20210730/Resource/Compute/AmazonEc2R5GdInstance.png) | ![illustration for AmazonEc2R5GdInstance](../../../aws-20210730/Resource/Compute/AmazonEc2R5GdInstance.Local.png) | ![illustration for AmazonEc2R5GdInstanceCard](../../../aws-20210730/Resource/Compute/AmazonEc2R5GdInstanceCard.Local.png) | ![illustration for AmazonEc2R5GdInstanceGroup](../../../aws-20210730/Resource/Compute/AmazonEc2R5GdInstanceGroup.Local.png) |




## AmazonEc2R5GdInstance

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonEc2R5GdInstance
include('aws-20210730/Resource/Compute/AmazonEc2R5GdInstance')

' renders the element
AmazonEc2R5GdInstance('AmazonEc2R5GdInstance', 'Amazon Ec2 R5 Gd Instance', 'an optional tech label')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonEc2R5GdInstance
include('aws-20210730/Resource/Compute/AmazonEc2R5GdInstance')

' renders the element
AmazonEc2R5GdInstance('AmazonEc2R5GdInstance', 'Amazon Ec2 R5 Gd Instance', 'an optional tech label')
@enduml
```

## AmazonEc2R5GdInstanceCard

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonEc2R5GdInstanceCard
include('aws-20210730/Resource/Compute/AmazonEc2R5GdInstance')

' renders the element
AmazonEc2R5GdInstanceCard('AmazonEc2R5GdInstanceCard', 'Amazon Ec2 R5 Gd Instance Card', 'an optional description')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonEc2R5GdInstanceCard
include('aws-20210730/Resource/Compute/AmazonEc2R5GdInstance')

' renders the element
AmazonEc2R5GdInstanceCard('AmazonEc2R5GdInstanceCard', 'Amazon Ec2 R5 Gd Instance Card', 'an optional description')
@enduml
```

## AmazonEc2R5GdInstanceGroup

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonEc2R5GdInstanceGroup
include('aws-20210730/Resource/Compute/AmazonEc2R5GdInstance')

' renders the element
AmazonEc2R5GdInstanceGroup('AmazonEc2R5GdInstanceGroup', 'Amazon Ec2 R5 Gd Instance Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonEc2R5GdInstanceGroup
include('aws-20210730/Resource/Compute/AmazonEc2R5GdInstance')

' renders the element
AmazonEc2R5GdInstanceGroup('AmazonEc2R5GdInstanceGroup', 'Amazon Ec2 R5 Gd Instance Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```
